Scheme (scheme) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Scheme (scheme)

# Scheme (`scheme`)

## Scheme

The scheme package implements and defines the underlying workflow model.

The `Scheme` class represents the workflow and is composed of a set of `SchemeNode` connected with `SchemeLink`, defining an directed acyclic graph (DAG). Additionally instances of `SchemeArrowAnnotation` or `SchemeTextAnnotation` can be inserted into the scheme.

- Scheme (`scheme`)
  - Scheme Workflow
- Scheme Node (`node`)
  - Scheme Node
- Scheme Link (`link`)
  - Scheme Link
- Scheme Annotations (`annotations`)
  - Scheme Annotations
- Scheme Serialization (`readwrite`)